==================================
Nova-dpm specifications for Queens
==================================

Template:

.. toctree::
   :maxdepth: 1

   Specification Template (Queens release) <template>

Specs implemented in Queens:

.. toctree::
   :glob:
   :maxdepth: 1

   implemented/*

Specs proposed / approved for Queens:

.. toctree::
   :glob:
   :maxdepth: 1

   approved/*
